#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_NEXT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_NEXT_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/next.hpp>

#endif
